<?php

namespace MatrixAddons\EasyInvoice\Admin\Settings;


use MatrixAddons\EasyInvoice\Admin\Emails\DefaultEmailMessages;
use MatrixAddons\EasyInvoice\Admin\Setting_Base;
use MatrixAddons\EasyInvoice\Admin\Settings;

if (!defined('ABSPATH')) {
	exit;
}

class InvoiceSettings extends Setting_Base
{

	/**
	 * Constructor.
	 */
	public function __construct()
	{
		$this->id = 'ei_invoice';
		$this->label = __('Invoice Settings', 'easy-invoice');

		parent::__construct();
	}

	/**
	 * Get sections.
	 *
	 * @return array
	 */
	public function get_sections()
	{
		$sections = array(
			'' => __('General', 'easy-invoice'),
			'business' => __('Business', 'easy-invoice'),
			'currency' => __('Currency', 'easy-invoice'),
			'tax' => __('Tax', 'easy-invoice'),
 			'text_translation' => __('Text Translation', 'easy-invoice'),
		);

		return apply_filters('easy_invoice_get_sections_' . $this->id, $sections);
	}

	/**
	 * Output the settings.
	 */
	public function output()
	{
		global $current_section;

		$settings = $this->get_settings($current_section);

		Settings::output_fields($settings);
	}

	/**
	 * Save settings.
	 */
	public function save()
	{
		global $current_section;

		$settings = $this->get_settings($current_section);
		Settings::save_fields($settings);

		if ($current_section) {
			do_action('easy_invoice_update_options_' . $this->id . '_' . $current_section);
		}
	}

	/**
	 * Get settings array.
	 *
	 * @param string $current_section Current section name.
	 * @return array
	 */
	public function get_settings($current_section = '')
	{
		if ('currency' === $current_section) {
			$settings = array(
				array(
					'title' => __('Currency Settings', 'easy-invoice'),
					'type' => 'title',
					'desc' => '',
					'id' => 'easy_invoice_currency_options',
				),
				array(
					'title' => __('Currency', 'easy-invoice'),
					'id' => 'easy_invoice_currency',
					'type' => 'select',
					'default' => 'USD',
					'options' => easy_invoice_get_all_currency_with_symbol()
				),
				array(
					'title' => __('Currency Symbol Type', 'easy-invoice'),
					'desc' => __('Currency Symbol Type', 'easy-invoice'),
					'id' => 'easy_invoice_currency_symbol_type',
					'type' => 'select',
					'options' => array(
						'code' => __('Currency Code', 'easy-invoice'),
						'symbol' => __('Currency Symbol', 'easy-invoice')
					),
					'default' => 'symbol'
				),
				array(
					'title' => __('Currency symbol/code position', 'easy-invoice'),
					'id' => 'easy_invoice_currency_position',
					'default' => 'left',
					'type' => 'select',
					'options' => easy_invoice_get_currency_positions()
				),
				array(
					'title' => __('Thousand Separator', 'easy-invoice'),
					'desc' => __('Thousand separator for price.', 'easy-invoice'),
					'id' => 'easy_invoice_thousand_separator',
					'default' => ',',
					'type' => 'text',
				),
				array(
					'title' => __('Number of Decimals', 'easy-invoice'),
					'desc' => __('Number of decimals shown in price.', 'easy-invoice'),
					'id' => 'easy_invoice_price_number_decimals',
					'default' => 2,
					'type' => 'number',
				),
				array(
					'title' => __('Decimal Separator', 'easy-invoice'),
					'desc' => __('Decimal separator for price.', 'easy-invoice'),
					'id' => 'easy_invoice_decimal_separator',
					'default' => '.',
					'type' => 'text',
				),
				array(
					'type' => 'sectionend',
					'id' => 'easy_invoice_currency_options',
				),

			);

		} else if ('tax' === $current_section) {
			$settings = array(
				array(
					'title' => __('Tax Options', 'easy-invoice'),
					'type' => 'title',
					'desc' => '',
					'id' => 'easy_invoice_tax_options',
				),
				array(
					'title' => __('How do you enter tax?', 'easy-invoice'),
					'id' => 'easy_invoice_tax_type',
					'type' => 'radio',
					'options' => array(
						'inclusive' => __('I will enter price inclusive of tax', 'easy-invoice'),
						'exclusive' => __('I will enter price exclusive of tax', 'easy-invoice'),
					),
					'default' => 'exclusive'
				),

				array(
					'title' => __('Tax Percentage', 'easy-invoice'),
					'id' => 'easy_invoice_tax_percentage',
					'type' => 'number',
					'default' => 10,
					'custom_attributes' => array(
						'step' => 'any',

					)
				),
				array(
					'type' => 'sectionend',
					'id' => 'easy_invoice_tax_options',
				),

			);

		} else if ('business' === $current_section) {

			$logo_id = absint(get_theme_mod('custom_logo'));
			$settings = array(
				array(
					'title' => __('Business Settings', 'easy-invoice'),
					'type' => 'title',
					'desc' => '',
					'id' => 'easy_invoice_business_options',
				),
				array(
					'title' => __('Business Logo', 'easy-invoice'),
					'id' => 'easy_invoice_business_logo',
					'type' => 'image',
					'default' => $logo_id,
				),
				array(
					'title' => __('Business Name', 'easy-invoice'),
					'desc' => __('Your business name goes here', 'easy-invoice'),
					'id' => 'easy_invoice_business_name',
					'type' => 'text',
					'default' => get_bloginfo('name')
				),
				array(
					'title' => __('Business Address', 'easy-invoice'),
					'id' => 'easy_invoice_business_address',
					'desc' => __('HTML tags supports: a, br, em, strong, hr, p, h1 to h4', 'easy-invoice'),
					'type' => 'textarea',
					'allowed_html' => array(
						'a' => array(
							'href' => array(),
							'target' => array()
						),
						'br' => array(),
						'em' => array(),
						'strong' => array(),
						'hr' => array(),
						'p' => array(),
						'h1' => array(),
						'h2' => array(),
						'h3' => array(),
						'h4' => array(),
						'h5' => array(),
						'h6' => array(),
					),
					'default' =>
						'Your main address
123 Somewhere Street
Your City Address 12345'
				),

				array(
					'title' => __('Additional Business Info', 'easy-invoice'),
					'id' => 'easy_invoice_business_additional_info',
					'desc' => __('Extra business info such as Business Number, phone number or email address and format it anyway you like. You can add your VAT number or ABN here.HTML tags supports: a, br, em, strong, hr, p, h1 to h4', 'easy-invoice'),
					'type' => 'textarea',
					'allowed_html' => array(
						'a' => array(
							'href' => array(),
							'target' => array()
						),
						'br' => array(),
						'em' => array(),
						'strong' => array(),
						'hr' => array(),
						'p' => array(),
						'h1' => array(),
						'h2' => array(),
						'h3' => array(),
						'h4' => array(),
						'h5' => array(),
						'h6' => array(),
					),
					'default' => get_option('admin_email')
				),
				array(
					'title' => __('Website URL', 'easy-invoice'),
					'desc' => __('Your business website URL', 'easy-invoice'),
					'id' => 'easy_invoice_business_website_url',
					'type' => 'url',
					'default' => site_url()
				),
				array(
					'type' => 'sectionend',
					'id' => 'easy_invoice_business_options',
				),

			);

		} else if ('text_translation' == $current_section) {

			$translation_texts = easy_invoice_get_all_texts();


			$settings = array(
				array(
					'title' => __('Text Translation Settings', 'easy-invoice'),
					'type' => 'title',
					'desc' => '',
					'id' => 'easy_invoice_text_translation_options',
				),
			);

			foreach ($translation_texts as $text_id => $text_label) {

				array_push($settings, array(
					'title' => sanitize_text_field($text_label),
					'id' => 'easy_invoice_text_' . sanitize_text_field($text_id),
					'type' => 'text',
					'default' => sanitize_text_field($text_label)
				));
			}

			array_push($settings, array(
				'type' => 'sectionend',
				'id' => 'easy_invoice_text_translation_options',
			));
		}  else {

			$footer_text = 'Thanks for choosing <a href="' . esc_url(site_url()) . '">' . esc_html(get_bloginfo('name')) . '</a> | <a href="mailto:' . esc_attr(get_option('admin_email')) . '">' . esc_html(get_option('admin_email')) . '</a>';
			$settings = array(
				array(
					'title' => __('General Settings', 'easy-invoice'),
					'type' => 'title',
					'desc' => '',
					'id' => 'easy_invoice_general_options',
				),
				array(
					'title' => __('Invoice Prefix', 'easy-invoice'),
					'id' => 'easy_invoice_number_prefix',
					'type' => 'text',
					'default' => 'EIN_'
				),


				array(
					'title' => __('Show/Hide Adjust Field', 'easy-invoice'),
					'desc' => __('Enable/Disable Adjust field. Tick this to show adjust field', 'easy-invoice'),
					'id' => 'easy_invoice_show_hide_adjust',
					'type' => 'checkbox',
					'default' => 'yes'
				),
				array(
					'title' => __('Terms & Conditions', 'easy-invoice'),
					'id' => 'easy_invoice_terms_conditions',
					'desc' => __('Terms and conditions that will be displayed on your invoice', 'easy-invoice'),
					'type' => 'textarea',
					'default' => 'Payment is due within 30 days from date of invoice'
				),

				array(
					'title' => __('Footer Text', 'easy-invoice'),
					'id' => 'easy_invoice_footer_text',
					'desc' => __('You can modify your invoice footer text from here.HTML tags supports: a, br, em, strong, hr, p, h1 to h4', 'easy-invoice'),
					'type' => 'textarea',
					'allowed_html' => array(
						'a' => array(
							'href' => array(),
							'target' => array()
						),
						'br' => array(),
						'em' => array(),
						'strong' => array(),
						'hr' => array(),
						'p' => array(),
						'h1' => array(),
						'h2' => array(),
						'h3' => array(),
						'h4' => array(),
						'h5' => array(),
						'h6' => array(),
					),
					'default' => $footer_text
				),
				array(
					'type' => 'sectionend',
					'id' => 'easy_invoice_general_options',
				),

			);
		}

		return apply_filters('easy_invoice_get_settings_' . $this->id, $settings, $current_section);
	}
}
