<?php

namespace MatrixAddons\EasyInvoice;

use MatrixAddons\EasyInvoice\Repositories\InvoiceRepository;

class Ajax
{
	public static function init()
	{
		$self = new self();
		add_action('wp_ajax_send_email', array($self, 'send_email'));
		add_action('wp_ajax_nopriv_send_email', array($self, 'send_email'));

		add_action('wp_ajax_proceed_to_payment', array($self, 'proceed_to_payment'));
		add_action('wp_ajax_nopriv_proceed_to_payment', array($self, 'proceed_to_payment'));
	}

	public function send_email()
	{
		if (!current_user_can('manage_options')) {

			wp_send_json_error('Permission denied');

			exit;
		}
		$action = isset($_POST['action']) ? sanitize_text_field($_POST['action']) : '';

		$nonce = isset($_POST['nonce']) ? sanitize_text_field($_POST['nonce']) : '';

		$invoice_id = isset($_POST['invoice_id']) ? absint($_POST['invoice_id']) : 0;

		if (!wp_verify_nonce($nonce, $action) || $invoice_id < 0 || get_post_type($invoice_id) !== 'easy-invoice') {

			easy_invoice_load_template('parts.error-page', array('error_text' => 'Something went wrong, please try again.'));

		}
		global $easy_invoice;

		$easy_invoice = new InvoiceRepository($invoice_id);

		$client_email = $easy_invoice->get_client_email();

		if ($client_email == '') {

			easy_invoice_load_template('parts.error-page', array('error_text' => 'Client email address not found.'));

			exit;
		}

		do_action('easy_invoice_on_invoice_available', $invoice_id);


		wp_send_json_success('Email successfully send.');

	}


	public function proceed_to_payment()
	{

		$action = isset($_POST['action']) ? sanitize_text_field($_POST['action']) : '';

		$nonce = isset($_POST['nonce']) ? sanitize_text_field($_POST['nonce']) : '';

		$invoice_id = isset($_POST['invoice_id']) ? absint($_POST['invoice_id']) : 0;

		if (!wp_verify_nonce($nonce, $action) || $invoice_id < 0 || get_post_type($invoice_id) !== 'easy-invoice') {

			easy_invoice_load_template('parts.error-page', array('error_text' => 'Something went wrong, please try again.'));

			exit;
		}

		if (!easy_invoice_enable_proceed_to_payment($invoice_id)) {

			easy_invoice_load_template('parts.error-page', array('error_text' => 'Unable to proceed payment for this invoice'));

			exit;
		}
		global $easy_invoice;

		$easy_invoice = new InvoiceRepository($invoice_id);

		$client_email = $easy_invoice->get_client_email();

		if ($client_email == '') {

			easy_invoice_load_template('parts.error-page', array('error_text' => 'Client email not found.'));

			exit;
		}

		do_action('easy_invoice_payment_page', $invoice_id);

		exit;

	}


}
