<?php

use MatrixAddons\EasyInvoice\Repositories\InvoiceRepository;


if (!function_exists('easy_invoice_get_invoice_options')) {

	function easy_invoice_get_invoice_options($invoice_id = null)
	{
		$invoice_id = is_null($invoice_id) ? get_the_ID() : absint($invoice_id);

		return new InvoiceRepository($invoice_id);

	}
}
if (!function_exists('easy_invoice_get_business_name')) {
	function easy_invoice_get_business_name()
	{
		$business_logo = absint(get_option('easy_invoice_business_logo', ''));

		$logo_src = $business_logo > 0 ? easy_invoice_get_attachment_image_url($business_logo) : '';

		?>
		<a target="_blank" href="<?php echo esc_url(site_url()) ?>">
			<?php if ($logo_src === '') { ?>
				<h1><?php echo esc_html(get_bloginfo('name')) ?></h1>
			<?php } else { ?>
				<img src="<?php echo esc_url($logo_src) ?>" class="ei-business-logo"/>
			<?php } ?>
		</a>
		<?php
	}
}

if (!function_exists('easy_invoice_get_invoice_label')) {
	function easy_invoice_get_invoice_label()
	{
		echo esc_html(easy_invoice_get_text('invoice'));
	}
}


if (!function_exists('easy_invoice_get_from_address')) {
	function easy_invoice_get_from_address()
	{ ?>
		<div class="title"><strong><?php echo esc_html(easy_invoice_get_text('from')); ?></strong></div>

		<div class="site-url"><a target="_blank"
								 href="<?php echo esc_url(site_url()) ?>"><?php echo esc_html(get_option('easy_invoice_business_name', get_bloginfo('name'))); ?></a>
		</div>
		<div class="address">
			<p><?php easy_invoice_print_html_text(wpautop(easy_invoice_business_address())); ?>
			</p>
		</div>
		<div class="extra">
			<p><?php easy_invoice_print_html_text(wpautop(get_option('easy_invoice_business_additional_info'), get_option('admin_email'))); ?></p>
		</div>
		<?php
	}
}


if (!function_exists('easy_invoice_get_to_address')) {
	function easy_invoice_get_to_address()
	{
		global $easy_invoice;

		?>
		<div class="title"><strong><?php echo esc_html(easy_invoice_get_text('to')); ?></strong></div>
		<?php if ($easy_invoice->get_client_name() !== '' && $easy_invoice->get_client_url() !== '') { ?>
		<div class="site-url"><a target="_blank"
								 href="<?php echo esc_url($easy_invoice->get_client_url()) ?>"><?php echo esc_html($easy_invoice->get_client_name()); ?></a>
		</div>
	<?php } else if ($easy_invoice->get_client_name() !== '') { ?>
		<div class="site-url"><p><?php echo esc_html($easy_invoice->get_client_name()); ?></p></div>
	<?php } ?>
		<?php if ($easy_invoice->get_client_additional_info() !== '') { ?>
		<div class="address">
			<p>
				<?php easy_invoice_print_html_text(wpautop($easy_invoice->get_client_additional_info())); ?>
			</p>
		</div>
	<?php } ?>
		<div class="extra">
			<p><?php echo esc_html($easy_invoice->get_client_email()) ?></p>
		</div>

		<?php
	}
}

if (!function_exists('easy_invoice_get_invoice_description')) {
	function easy_invoice_get_invoice_description()
	{
		global $easy_invoice;

		return $easy_invoice->get_description();
	}
}

if (!function_exists('easy_invoice_get_download_as_pdf_url')) {
	function easy_invoice_get_download_as_pdf_url($invoice_id)
	{
		return add_query_arg(array(
				'action' => 'download_as_pdf',
				'nonce' => wp_create_nonce('download_as_pdf'),
		), get_permalink($invoice_id));
	}
}


if (!function_exists('easy_invoice_get_invoice_number')) {
	function easy_invoice_get_invoice_number()
	{
		$pad_len = 7;

		$invoice_number = absint(get_option('easy_invoice_invoice_number', 0));

		$invoice_number = $invoice_number + 1;

		$invoice_number = $invoice_number < 1 ? 1 : $invoice_number;

		$prefix = get_option('easy_invoice_number_prefix', 'EIN_');

		update_option('easy_invoice_invoice_number', absint($invoice_number));

		if (is_string($prefix)) {
			return sprintf("%s%s", $prefix, str_pad($invoice_number, $pad_len, "0", STR_PAD_LEFT));
		}

		return str_pad($invoice_number, $pad_len, "0", STR_PAD_LEFT);
	}
}
if (!function_exists('easy_invoice_update_invoice_status')) {

	function easy_invoice_update_invoice_status($invoice_id = 0, $status = '')
	{
		$easy_invoice_invoice_statuses = easy_invoice_get_invoice_statuses();

		if (absint($invoice_id) < 1 || !isset($easy_invoice_invoice_statuses[$status])) {

			return false;
		}

		do_action('easy_invoice_before_invoice_status_change', array(
				'invoice_id' => $invoice_id,
				'status' => $status
		));

		update_post_meta($invoice_id, 'invoice_status', sanitize_text_field($status));

		do_action('easy_invoice_after_invoice_status_change', array(
				'invoice_id' => $invoice_id,
				'status' => $status
		));

		return true;
	}
}

if (!function_exists('easy_invoice_get_invoice_statuses')) {
	function easy_invoice_get_invoice_statuses()
	{

		return [
				'available' => __("Available", "easy-invoice"),
				'draft' => __("Draft", "easy-invoice"),
				'overdue' => __("Overdue", "easy-invoice"),
				'paid' => __("Paid", "easy-invoice"),
				'unpaid' => __("Unpaid", "easy-invoice"),
				'cancelled' => __("Cancelled", "easy-invoice"),
		];
	}
}

if (!function_exists('easy_invoice_get_hook')) {
	function easy_invoice_get_hook($hook_id)
	{
		global $easy_invoice_hooks;

		if (!is_array($easy_invoice_hooks)) {
			return null;
		}
		if (isset($easy_invoice_hooks[$hook_id])) {
			return $easy_invoice_hooks[$hook_id];
		}
		return null;
	}
}


function easy_invoice_maybe_flush_rewrite_rules()
{
	if ('yes' === get_option('easy_invoice_queue_flush_rewrite_rules')) {
		update_option('easy_invoice_queue_flush_rewrite_rules', 'no');
		flush_rewrite_rules();
	}
}

if (!function_exists(('easy_invoice_get_var'))) {
	function easy_invoice_get_var(&$var, $default = null)
	{
		return isset($var) ? $var : $default;
	}
}


if (!function_exists('easy_invoice_get_premium_addons')) {

	function easy_invoice_get_premium_addons()
	{
		return apply_filters('easy_invoice_premium_addons', array());
	}
}
