<?php

namespace MatrixAddons\EasyInvoice\Hooks;

use MatrixAddons\EasyInvoice\Repositories\InvoiceRepository;
use MatrixAddons\EasyInvoice\Repositories\PaymentRepository;

class ListTable
{
	public function __construct()
	{
		add_filter('manage_edit-easy-invoice_columns', array($this, 'invoice_column'));
		add_action('manage_easy-invoice_posts_custom_column', array($this, 'invoice_column_value'), 15, 2);


		add_filter('manage_edit-easy-invoice-payment_columns', array($this, 'invoice_payment_column'));
		add_action('manage_easy-invoice-payment_posts_custom_column', array($this, 'invoice_payment_column_value'), 15, 2);

	}


	public function invoice_column($columns)
	{

		unset($columns['date']);
		$columns['invoice_number'] = __('Invoice Number', 'easy-invoice');
		$columns['client'] = __('Client', 'easy-invoice');
		$columns['status'] = __('Status', 'easy-invoice');
		$columns['due_date'] = __('Due Date', 'easy-invoice');
		$columns['due_amount'] = __('Due Amount', 'easy-invoice');

		$columns['date'] = __('Date', 'easy-invoice');
		$columns['action'] = __('Action', 'easy-invoice');

		return $columns;

	}

	public function invoice_column_value($column, $a)
	{
		global $post;

		$invoice_id = $post->ID;

		$invoice_repository = new InvoiceRepository($invoice_id);

		switch ($column) {
			case "invoice_number":
				echo '<code style="font-size:15px;">' . esc_html($invoice_repository->get_invoice_number()) . '</code>';
				break;
			case "client":
				echo '<span>' . esc_html($invoice_repository->get_client_name()) . '</span>';
				echo '<br/>';
				echo '<span>' . esc_html($invoice_repository->get_client_email()) . '</span>';
				break;
			case "status":
				$invoice_status = easy_invoice_get_invoice_statuses();
				if (isset($invoice_status[$invoice_repository->get_invoice_status()])) {
					echo '<span>' . esc_html($invoice_status[$invoice_repository->get_invoice_status()]) . '</span>';
				} else {
					echo '<span>N/A</span>';
				}
				break;
			case "due_date":
				echo '<span>' . esc_html($invoice_repository->get_due_date()) . '</span>';
				break;
			case "due_amount":
				echo '<span>' . esc_html(easy_invoice_get_price($invoice_repository->get_due_amount(), '', $invoice_id)) . '</span>';
				break;
			case "action":
				echo '<a style="display:inline-flex;justify-content:space-between; align-items: center; text-align:center; margin-right:5px;" target="_blank" title="View" class="button button-secondary" href="' . get_permalink($invoice_id) . '"><span class="dashicons dashicons-visibility"></span></a>';
				echo '<a style="display:inline-flex;justify-content:space-between; align-items: center; text-align:center;margin-right:5px;" target="_blank; margin-right:5px;" title="Download as PDF" class="button button-secondary" href="' . esc_url(easy_invoice_get_download_as_pdf_url($invoice_id)) . '"><span class="dashicons dashicons-pdf"></span></a>';
				/*echo '<a style="display:inline-flex;justify-content:space-between; align-items: center; text-align:center;" target="_blank" title="Download as PDF" class="button button-secondary" href="#"><span class="dashicons dashicons-email"></span></a>';*/

				break;


		}
	}


	public function invoice_payment_column($columns)
	{

		unset($columns['date']);
		$columns['payment_gateway'] = __('Payment Gateway', 'easy-invoice');
		$columns['paid_amount'] = __('Paid Amount', 'easy-invoice');
		$columns['status'] = __('Payment Status', 'easy-invoice');
		$columns['invoice'] = __('Invoice', 'easy-invoice');
		$columns['payment_note'] = __('Payment Note', 'easy-invoice');
		$columns['payment_date'] = __('Payment Date', 'easy-invoice');


		return $columns;

	}

	public function invoice_payment_column_value($column, $a)
	{
		global $post;

		$payment_id = $post->ID;

		$payment = new PaymentRepository($payment_id);

		$invoice_id = $payment->get_invoice_id();


		$all_payment_status = PaymentRepository::payment_statuses();

		switch ($column) {

			case "payment_gateway":
				$gateway_lists = easy_invoice_get_payment_gateway_lists();

				$gateway_id = $payment->get_gateway();

				if ($gateway_id === '') {

					echo '<span>N/A</span>';

				} else if (isset($gateway_lists[$gateway_id])) {

					echo '<span>' . esc_html($gateway_lists[$gateway_id]) . '</span>';
				} else {
					echo '<span>' . esc_html($gateway_id) . '</span>';
				}
				break;
			case "paid_amount":
				echo '<span>' . esc_html(easy_invoice_get_price($payment->get_paid_amount(), '', $invoice_id)) . '</span>';
				break;
			case "status":
				if (isset($all_payment_status[$payment->get_status()])) {
					echo '<span>' . esc_html($all_payment_status[$payment->get_status()]) . '</span>';
				} else {
					echo '<span>N/A</span>';
				}
				break;
			case "invoice":
				if (absint($invoice_id) > 0) {
					echo '<a href="' . get_permalink($invoice_id) . '" target="_blank">' . esc_html(get_the_title($invoice_id)) . '</a>';
				} else {
					echo '<span > N / A</span > ';
				}
				break;
			case "payment_note":
				echo '<p>' . esc_html($payment->get_note()) . '</p>';
				break;
			case "payment_date":
				echo '<p>' . esc_html($payment->get_payment_date()) . '</p>';
				break;


		}
	}
}
